@@ -2,26 +2,28 @@
 $description America-based television network centred towards business and capital market programming.
 $url bloomberg.com
 $type live, vod
+$metadata title
 """
 
 import logging
 import re
 
 from streamlink.plugin import Plugin, PluginError, pluginmatcher
-from streamlink.plugin.api import validate
+from streamlink.plugin.api import useragents, validate
 from streamlink.stream.hls import HLSStream
 
+
 log = logging.getLogger(__name__)
 
 
-@pluginmatcher(re.compile(r"""
-    https?://(?:www\.)?bloomberg\.com/
-    (?:
-        (?P<live>live)(?:/(?P<channel>[^/]+))?
-        |
-        news/videos/[^/]+/[^/]+
-    )
-""", re.VERBOSE))
+@pluginmatcher(
+    name="live",
+    pattern=re.compile(r"https?://(?:www\.)?bloomberg\.com/live(?:/(?P<channel>[^/]+))?"),
+)
+@pluginmatcher(
+    name="vod",
+    pattern=re.compile(r"https?://(?:www\.)?bloomberg\.com/news/videos/[^/]+/[^/]+"),
+)
 class Bloomberg(Plugin):
     LIVE_API_URL = "https://cdn.gotraffic.net/projector/latest/assets/config/config.min.json?v=1"
     VOD_API_URL = "https://www.bloomberg.com/api/embed?id={0}"
@@ -32,8 +34,8 @@ class Bloomberg(Plugin):
             {"live": {"channels": {"byChannelId": {
                 channel: validate.all(
                     {"liveId": str},
-                    validate.get("liveId")
-                )
+                    validate.get("liveId"),
+                ),
             }}}},
             validate.get(("live", "channels", "byChannelId", channel)),
         )
@@ -50,13 +52,13 @@ class Bloomberg(Plugin):
                 live_id: {
                     validate.optional("cdns"): validate.all(
                         [{"streams": [{
-                            "url": validate.url()
+                            "url": validate.url(),
                         }]}],
-                        validate.transform(lambda x: [urls["url"] for y in x for urls in y["streams"]])
-                    )
-                }
+                        validate.transform(lambda x: [urls["url"] for y in x for urls in y["streams"]]),
+                    ),
+                },
             }},
-            validate.get(("livestreams", live_id, "cdns"))
+            validate.get(("livestreams", live_id, "cdns")),
         ))
 
     def _get_vod_streams(self, data):
@@ -64,21 +66,21 @@ class Bloomberg(Plugin):
             validate.any(
                 validate.all(
                     {"video": {"videoStory": dict}},
-                    validate.get(("video", "videoStory"))
+                    validate.get(("video", "videoStory")),
                 ),
                 validate.all(
                     {"quicktakeVideo": {"videoStory": dict}},
-                    validate.get(("quicktakeVideo", "videoStory"))
-                )
+                    validate.get(("quicktakeVideo", "videoStory")),
+                ),
             ),
             {"video": {
-                "bmmrId": str
+                "bmmrId": str,
             }},
-            validate.get(("video", "bmmrId"))
+            validate.get(("video", "bmmrId")),
         )
         schema_url = validate.all(
             {"url": validate.url()},
-            validate.get("url")
+            validate.get("url"),
         )
 
         try:
@@ -94,31 +96,34 @@ class Bloomberg(Plugin):
             {
                 validate.optional("secureStreams"): [schema_url],
                 validate.optional("streams"): [schema_url],
-                "title": str
+                "title": str,
             },
-            validate.union_get("secureStreams", "streams", "title")
+            validate.union_get("secureStreams", "streams", "title"),
         ))
 
         return secureStreams or streams
 
     def _get_streams(self):
-        del self.session.http.headers["Accept-Encoding"]
+        self.session.http.headers.clear()
+        self.session.http.headers["User-Agent"] = useragents.CHROME
 
-        try:
-            data = self.session.http.get(self.url, schema=validate.Schema(
-                validate.parse_html(),
-                validate.xml_xpath_string(".//script[contains(text(),'window.__PRELOADED_STATE__')][1]/text()"),
-                str,
-                validate.regex(re.compile(r"^\s*window\.__PRELOADED_STATE__\s*=\s*({.+})\s*;?\s*$", re.DOTALL)),
-                validate.get(1),
-                validate.parse_json(),
-            ))
-        except PluginError:
+        data = self.session.http.get(self.url, schema=validate.Schema(
+            validate.parse_html(),
+            validate.xml_xpath_string(".//script[contains(text(),'window.__PRELOADED_STATE__')][1]/text()"),
+            validate.none_or_all(
+                re.compile(r"\bwindow\.__PRELOADED_STATE__\s*=\s*(?P<json>{.+?})\s*;(?:\s|$)"),
+                validate.none_or_all(
+                    validate.get("json"),
+                    validate.parse_json(),
+                ),
+            ),
+        ))
+        if not data:
             log.error("Could not find JSON data. Invalid URL or bot protection...")
             return
 
-        if self.match.group("live"):
-            streams = self._get_live_streams(data, self.match.group("channel") or self.DEFAULT_CHANNEL)
+        if self.matches["live"]:
+            streams = self._get_live_streams(data, self.match["channel"] or self.DEFAULT_CHANNEL)
         else:
             streams = self._get_vod_streams(data)
 
